#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Main;
use Vhffs::Constants;
use Vhffs::Panel::Main;
use Vhffs::Panel::Template;
use Vhffs::Functions;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;

my $vhffs = $panel->{'vhffs'};
my $cgi = $panel->{'cgi'};
my $templatedir = $panel->{'templatedir'};

$panel->check_public();

my $template;
my $subtemplate;
my $repos;
my $files;
my $objs;

my $name = $cgi->param("name");


my $group;
my $message;

if( ! defined $name )
{
	$template = new HTML::Template( filename => $templatedir.'/public/simplemsg.tmpl' );
	$message = gettext( "CGI Error !");
	$template->param( MESSAGE => $message );
}
elsif( ! defined ($group= Vhffs::Group::get_by_groupname( $vhffs , $name ) ) )
{

	$template = new HTML::Template( filename => $templatedir.'/public/simplemsg.tmpl' );
	$message = gettext( "No such group");
	$template->param( MESSAGE => $message );

}
else
{
    $name = Vhffs::Functions::check_arg( $name );
	$template = new Vhffs::Panel::Template( filename => $templatedir."/public/group.tmpl", 
                        die_on_bad_params => 0,
                        loop_context_vars => 1,
                        global_var => 1,
                        functions => { obfuscate_email => \&obfuscate_email } );
    $template->param( URL_PANEL => $vhffs->get_config->get_panel->{'url'} );
    $template->param( VALUE_REALNAME => $group->get_realname );
    $template->param( VALUE_GROUPNAME => $group->get_groupname );
    $template->param( VALUE_DESCRIPTION => Vhffs::Panel::Main::format_description($group->get_description));
    $template->param( USERS => $group->get_users );

    if( $vhffs->get_config->get_service_availability('web') == 1 ) {
        use Vhffs::Panel::Web;
        $template->param( WEBSITES_TITLE => gettext('Websites for this group') );
        $template->param( WEBSITES => Vhffs::Panel::Web::get_websites_per_group($vhffs, $group->get_gid) );
    }

    if( $vhffs->get_config->get_service_availability('cvs') == 1 ) {
        use Vhffs::Panel::Cvs;
        $template->param( WEBCVS => $vhffs->get_config->get_service('cvs')->{'cvsweb_url'} );
        $template->param( CVSREPOS => Vhffs::Panel::Cvs::get_repos_per_group($vhffs, $group->get_gid ) );
    }

    if( $vhffs->get_config->get_service_availability('svn') == 1 ) {
        use Vhffs::Panel::Svn;
        $template->param( WEBSVN => $vhffs->get_config->get_service('svn')->{'svnweb_url'} );
        $template->param( SVNREPOS => Vhffs::Panel::Svn::get_repos_per_group($vhffs, $group->get_gid) );
    }

    if( $vhffs->get_config->get_service_availability('git') == 1 ) {
        use Vhffs::Panel::Git;
        $template->param( WEBGIT => $vhffs->get_config->get_service('git')->{'gitweb_url'} );
        $template->param( GITREPOS => Vhffs::Panel::Git::get_repos_per_group($vhffs, $group->get_gid) );
    }

    if( $vhffs->get_config->get_service_availability('mailinglist') == 1 ) {
        use Vhffs::Panel::MailingList;
        $template->param( ARCHIVESURL => $vhffs->get_config->get_service('mailinglist')->{'url_archives'} );
        $template->param( LISTS => Vhffs::Panel::MailingList::get_lists_per_group($vhffs, $group->get_gid) );
    }
}

# We've to wrap the function since $vhffs isn't reachable from templates
sub obfuscate_email {
    return Vhffs::Functions::obfuscate_email($vhffs, $_[0]);
}

$panel->light( $template );
$panel->display;

